summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2019-01-10 16:20:15 +0100
committerChristian Grothoff <christian@grothoff.org>2019-01-10 16:20:15 +0100
commit12123a7aed7815e7bd99d8af67d9210d20aa1e8e (patch)
treeff746dab4a06efc3e0a9f25ce3646478a42ebcbe /src/include
parent2a01aaa917c82abcaf395eb16f4008faf9250f41 (diff)
downloadexchange-12123a7aed7815e7bd99d8af67d9210d20aa1e8e.tar.gz
exchange-12123a7aed7815e7bd99d8af67d9210d20aa1e8e.tar.bz2
exchange-12123a7aed7815e7bd99d8af67d9210d20aa1e8e.zip
towards fixing #5447
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_auditor_service.h4
-rw-r--r--src/include/taler_exchange_service.h12
2 files changed, 14 insertions, 2 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index bf089e6cb..0118d72d7 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -460,6 +460,18 @@ TALER_EXCHANGE_test_signing_key (const struct TALER_EXCHANGE_Keys *keys,
/**
+ * Lookup the given @a pub in @a keys.
+ *
+ * @param keys the exchange's key set
+ * @param pub claimed current online signing key for the exchange
+ * @return NULL if @a pub was not found
+ */
+const struct TALER_EXCHANGE_SigningPublicKey *
+TALER_EXCHANGE_get_signing_key_details (const struct TALER_EXCHANGE_Keys *keys,
+ const struct TALER_ExchangePublicKeyP *pub);
+
+
+/**
* Get exchange's base URL.
*
* @param exchange exchange handle.
diff --git a/src/include/taler_auditor_service.h b/src/include/taler_auditor_service.h
index 78f878fed..5dbbf3d82 100644
--- a/src/include/taler_auditor_service.h
+++ b/src/include/taler_auditor_service.h
@@ -204,7 +204,7 @@ typedef void
* @param master_pub master public key of the exchange
* @param ep_start when does @a exchange_pub validity start
* @param ep_expire when does @a exchange_pub usage end
* @param ep_end when does @a exchange_pub legal validity end
* @param master_sig master signature affirming validity of @a exchange_pub
* @param cb the callback to call when a reply for this request is available
* @param cb_cls closure for the above callback
@@ -225,7 +225,7 @@ TALER_AUDITOR_deposit_confirmation (struct TALER_AUDITOR_Handle *auditor,
const struct TALER_MasterPublicKeyP *master_pub,
struct GNUNET_TIME_Absolute ep_start,
struct GNUNET_TIME_Absolute ep_expire,
- struct GNUNET_TIME_Absolute ep_end,
+ struct GNUNET_TIME_Absolute ep_legal_end,
const struct TALER_MasterSignatureP *master_sig,
TALER_AUDITOR_DepositConfirmationResultCallback cb,
void *cb_cls);
@@ -204,7 +204,7 @@ typedef void
* @param ep_start when does @a exchange_pub validity start
* @param ep_expire when does @a exchange_pub usage end
- * @param ep_end when does @a exchange_pub legal validity end
+ * @param ep_legal_end when does @a exchange_pub legal validity end
* @param master_sig master signature affirming validity of @a exchange_pub
* @param cb the callback to call when a reply for this request is available